@@ -1,8 +1,7 @@
 /*
  * The XML and API file generator module for SIP.
  *
- * Copyright (c) 2008
- * 	Phil Thompson <phil@river-bank.demon.co.uk>
+ * Copyright (c) 2009 Riverbank Computing Limited <info@riverbankcomputing.com>
  * 
  * This file is part of SIP.
  * 
@@ -22,6 +21,12 @@
 
 #define XML_VERSION_NR  0       /* The schema version number. */
 
+/* Icon numbers.  The values are those used by the eric IDE. */
+#define CLASS_ID        1
+#define METHOD_ID       4
+#define VARIABLE_ID     7
+#define ENUM_ID         10
+
 
 static void apiEnums(sipSpec *pt, moduleDef *mod, classDef *scope, FILE *fp);
 static void apiVars(sipSpec *pt, moduleDef *mod, classDef *scope, FILE *fp);
@@ -48,6 +53,7 @@ static void xmlIndent(int indent, FILE *fp);
 static const char *dirAttribute(argDef *ad);
 static void exportDefaultValue(argDef *ad, FILE *fp);
 static const char *pyType(argDef *ad, int sec, classDef **scope);
+static void prScopedPythonName(FILE *fp, classDef *scope, const char *pyname);
 
 
 /*
@@ -127,8 +133,8 @@ static int apiCtor(moduleDef *mod, classDef *scope, ctorDef *ct, int sec,
 
     /* Do the callable type form. */
     fprintf(fp, "%s.", mod->name);
-    prScopedPythonName(fp, scope->ecd, scope->pyname);
-    fprintf(fp, "(");
+    prScopedPythonName(fp, scope->ecd, scope->pyname->text);
+    fprintf(fp, "?%d(", CLASS_ID);
 
     need_comma = FALSE;
 
@@ -146,8 +152,8 @@ static int apiCtor(moduleDef *mod, classDef *scope, ctorDef *ct, int sec,
 
     /* Do the call __init__ form. */
     fprintf(fp, "%s.", mod->name);
-    prScopedPythonName(fp, scope->ecd, scope->pyname);
-    fprintf(fp, ".__init__(self");
+    prScopedPythonName(fp, scope->ecd, scope->pyname->text);
+    fprintf(fp, ".__init__?%d(self", CLASS_ID);
 
     for (a = 0; a < ct->pysig.nrArgs; ++a)
         apiArgument(&ct->pysig.args[a], FALSE, TRUE, sec, fp);
@@ -179,14 +185,14 @@ static void apiEnums(sipSpec *pt, moduleDef *mod, classDef *scope, FILE *fp)
         {
             fprintf(fp, "%s.", mod->name);
             prScopedPythonName(fp, ed->ecd, ed->pyname->text);
-            fprintf(fp, "\n");
+            fprintf(fp, "?%d\n", ENUM_ID);
         }
 
         for (emd = ed->members; emd != NULL; emd = emd->next)
         {
             fprintf(fp, "%s.", mod->name);
             prScopedPythonName(fp, ed->ecd, emd->pyname->text);
-            fprintf(fp, "\n");
+            fprintf(fp, "?%d\n", ENUM_ID);
         }
     }
 }
@@ -209,7 +215,7 @@ static void apiVars(sipSpec *pt, moduleDef *mod, classDef *scope, FILE *fp)
 
         fprintf(fp, "%s.", mod->name);
         prScopedPythonName(fp, vd->ecd, vd->pyname->text);
-        fprintf(fp, "\n");
+        fprintf(fp, "?%d\n", VARIABLE_ID);
     }
 }
 
@@ -224,7 +230,7 @@ static int apiOverload(moduleDef *mod, classDef *scope, overDef *od, int sec,
 
     fprintf(fp, "%s.", mod->name);
     prScopedPythonName(fp, scope, od->common->pyname->text);
-    fprintf(fp, "(");
+    fprintf(fp, "?%d(", METHOD_ID);
 
     nr_out = 0;
 
@@ -380,7 +386,7 @@ static void xmlClass(sipSpec *pt, moduleDef *mod, classDef *cd, FILE *fp)
     {
         xmlIndent(indent, fp);
         fprintf(fp, "<OpaqueClass name=\"");
-        prScopedPythonName(fp, cd->ecd, cd->pyname);
+        prScopedPythonName(fp, cd->ecd, cd->pyname->text);
         fprintf(fp, "\"/>\n");
 
         return;
@@ -388,7 +394,7 @@ static void xmlClass(sipSpec *pt, moduleDef *mod, classDef *cd, FILE *fp)
 
     xmlIndent(indent++, fp);
     fprintf(fp, "<Class name=\"");
-    prScopedPythonName(fp, cd->ecd, cd->pyname);
+    prScopedPythonName(fp, cd->ecd, cd->pyname->text);
     fprintf(fp, "\"");
 
     if (cd->picklecode != NULL)
@@ -411,7 +417,7 @@ static void xmlClass(sipSpec *pt, moduleDef *mod, classDef *cd, FILE *fp)
             if (cl != cd->supers)
                 fprintf(fp, " ");
 
-            prScopedPythonName(fp, cl->cd->ecd, cl->cd->pyname);
+            prScopedPythonName(fp, cl->cd->ecd, cl->cd->pyname->text);
         }
 
         fprintf(fp, "\"");
@@ -571,6 +577,7 @@ static void xmlFunction(classDef *scope, memberDef *md, overDef *oloads,
         int indent, FILE *fp)
 {
     overDef *od;
+    const char *default_str = "default=\"1\" ";
 
     for (od = oloads; od != NULL; od = od->next)
     {
@@ -586,12 +593,14 @@ static void xmlFunction(classDef *scope, memberDef *md, overDef *oloads,
         if (isSignal(od))
         {
             xmlIndent(indent, fp);
-            fprintf(fp, "<Signal name=\"");
+            fprintf(fp, "<Signal %sname=\"", default_str);
             prScopedPythonName(fp, scope, md->pyname->text);
             fprintf(fp, "\" sig=\"");
             xmlCppSignature(fp, od);
             fprintf(fp, "\"/>\n");
 
+            default_str = "";
+
             continue;
         }
 
@@ -639,7 +648,7 @@ static int xmlOverload(classDef *scope, memberDef *md, overDef *od,
     if (xtnds != NULL)
     {
         fprintf(fp, " extends=\"");
-        prScopedPythonName(fp, xtnds->ecd, xtnds->pyname);
+        prScopedPythonName(fp, xtnds->ecd, xtnds->pyname->text);
         fprintf(fp, "\"");
     }
 
@@ -869,7 +878,7 @@ static const char *pyType(argDef *ad, int sec, classDef **scope)
     switch (ad->atype)
     {
     case class_type:
-        type_name = ad->u.cd->pyname;
+        type_name = ad->u.cd->pyname->text;
         *scope = ad->u.cd->ecd;
         break;
 
@@ -993,3 +1002,19 @@ static const char *pyType(argDef *ad, int sec, classDef **scope)
 
     return type_name;
 }
+
+
+/*
+ * Generate a scoped Python name.
+ */
+static void prScopedPythonName(FILE *fp, classDef *scope, const char *pyname)
+{
+    if (scope != NULL)
+    {
+        prScopedPythonName(fp, scope->ecd, NULL);
+        fprintf(fp, "%s.", scope->pyname->text);
+    }
+
+    if (pyname != NULL)
+        fprintf(fp, "%s", pyname);
+}
