@@ -488,12 +488,16 @@ static void registerMetaType(classDef *cd)
     ctorDef *ct;
 
     /*
-     * We register types with Qt if the class is not abstract, has a public
-     * default ctor, a public copy ctor and a public dtor.
+     * We register types with Qt if the class is not abstract, doesn't have a
+     * private assignment operator, has a public default ctor, a public copy
+     * ctor and a public dtor.
      */
     if (isAbstractClass(cd))
         return;
 
+    if (cannotAssign(cd))
+        return;
+
     if (!isPublicDtor(cd))
         return;
 
@@ -1114,6 +1118,13 @@ static void setHierarchy(sipSpec *pt, classDef *base, classDef *cd,
                 if (isQObjectSubClass(mro->cd))
                     setIsQObjectSubClass(cd);
 
+                /*
+                 * If the super-class can't be assigned to then this one
+                 * cannot either.
+                 */
+                if (cannotAssign(mro->cd))
+                    setCannotAssign(cd);
+
                 /*
                  * If the super-class has a shadow then this one should have
                  * one as well.
@@ -1825,9 +1836,9 @@ static void resolvePySigTypes(sipSpec *pt, moduleDef *mod, classDef *scope,
             }
 
             if (isVirtual(od))
-                fatal("%s() unsupported function argument type - provide %%Method code, a valid %%VirtualCatcherCode and a valid C++ signature\n",od -> cppname);
+                fatal("%s() unsupported function argument type - provide %%MethodCode, a valid %%VirtualCatcherCode and a valid C++ signature\n",od -> cppname);
 
-            fatal("%s() unsupported function argument type - provide %%Method code and a valid %s signature\n",od -> cppname,(pt -> genc ? "C" : "C++"));
+            fatal("%s() unsupported function argument type - provide %%MethodCode and a valid %s signature\n",od -> cppname,(pt -> genc ? "C" : "C++"));
         }
 
         if (scope != NULL)
