@@ -3,8 +3,7 @@
  * C++ classes that provide a thread interface to interact properly with the
  * Python threading infrastructure.
  *
- * Copyright (c) 2008
- * 	Phil Thompson <phil@river-bank.demon.co.uk>
+ * Copyright (c) 2009 Riverbank Computing Limited <info@riverbankcomputing.com>
  * 
  * This file is part of SIP.
  * 
@@ -64,10 +63,10 @@ void *sipGetPending(sipWrapper **op, int *fp)
     pendingDef *pp;
 
 #ifdef WITH_THREAD
-    threadDef *td;
+    threadDef *thread;
 
-    if ((td = currentThreadDef()) != NULL)
-        pp = &td->pending;
+    if ((thread = currentThreadDef()) != NULL)
+        pp = &thread->pending;
     else
         pp = &pending;
 #else
@@ -90,7 +89,7 @@ void *sipGetPending(sipWrapper **op, int *fp)
 /*
  * Convert a new C/C++ pointer to a Python instance.
  */
-PyObject *sipWrapSimpleInstance(void *cppPtr, sipWrapperType *type,
+PyObject *sipWrapSimpleInstance(void *cppPtr, const sipTypeDef *td,
         sipWrapper *owner, int flags)
 {
     static PyObject *nullargs = NULL;
@@ -98,7 +97,7 @@ PyObject *sipWrapSimpleInstance(void *cppPtr, sipWrapperType *type,
     pendingDef old_pending;
     PyObject *self;
 #ifdef WITH_THREAD
-    threadDef *td;
+    threadDef *thread;
 #endif
 
     if (nullargs == NULL && (nullargs = PyTuple_New(0)) == NULL)
@@ -117,13 +116,13 @@ PyObject *sipWrapSimpleInstance(void *cppPtr, sipWrapperType *type,
      * setting the new one.
      */
 #ifdef WITH_THREAD
-    if ((td = currentThreadDef()) != NULL)
+    if ((thread = currentThreadDef()) != NULL)
     {
-        old_pending = td->pending;
+        old_pending = thread->pending;
 
-        td->pending.cpp = cppPtr;
-        td->pending.owner = owner;
-        td->pending.flags = flags;
+        thread->pending.cpp = cppPtr;
+        thread->pending.owner = owner;
+        thread->pending.flags = flags;
     }
     else
     {
@@ -141,11 +140,11 @@ PyObject *sipWrapSimpleInstance(void *cppPtr, sipWrapperType *type,
     pending.flags = flags;
 #endif
 
-    self = PyObject_Call((PyObject *)type, nullargs, NULL);
+    self = PyObject_Call((PyObject *)sipTypeAsPyTypeObject(td), nullargs, NULL);
 
 #ifdef WITH_THREAD
-    if (td != NULL)
-        td->pending = old_pending;
+    if (thread != NULL)
+        thread->pending = old_pending;
     else
         pending = old_pending;
 #else
@@ -163,24 +162,24 @@ PyObject *sipWrapSimpleInstance(void *cppPtr, sipWrapperType *type,
 void sip_api_start_thread(void)
 {
 #ifdef WITH_THREAD
-    threadDef *td;
+    threadDef *thread;
 
     /* Save the thread ID.  First, find an empty slot in the list. */
-    for (td = threads; td != NULL; td = td->next)
-        if (td->thr_ident == 0)
+    for (thread = threads; thread != NULL; thread = thread->next)
+        if (thread->thr_ident == 0)
             break;
 
-    if (td == NULL)
+    if (thread == NULL)
     {
-        td = sip_api_malloc(sizeof (threadDef));
-        td->next = threads;
-        threads = td;
+        thread = sip_api_malloc(sizeof (threadDef));
+        thread->next = threads;
+        threads = thread;
     }
 
-    if (td != NULL)
+    if (thread != NULL)
     {
-        td->thr_ident = PyThread_get_thread_ident();
-        td->pending.cpp = NULL;
+        thread->thr_ident = PyThread_get_thread_ident();
+        thread->pending.cpp = NULL;
     }
 #endif
 }
@@ -193,11 +192,11 @@ void sip_api_start_thread(void)
 void sip_api_end_thread(void)
 {
 #ifdef WITH_THREAD
-    threadDef *td;
+    threadDef *thread;
 
     /* We have the GIL at this point. */
-    if ((td = currentThreadDef()) != NULL)
-        td->thr_ident = 0;
+    if ((thread = currentThreadDef()) != NULL)
+        thread->thr_ident = 0;
 #endif
 }
 
@@ -210,14 +209,14 @@ void sip_api_end_thread(void)
  */
 static threadDef *currentThreadDef(void)
 {
-    threadDef *td;
+    threadDef *thread;
     long ident = PyThread_get_thread_ident();
 
-    for (td = threads; td != NULL; td = td->next)
-        if (td->thr_ident == ident)
+    for (thread = threads; thread != NULL; thread = thread->next)
+        if (thread->thr_ident == ident)
             break;
 
-    return td;
+    return thread;
 }
 
 #endif
